@@ -49,12 +49,14 @@ register_mlr3 = function() {
   x$add("clust.kkmeans", LearnerClustKKMeans)
   x$add("clust.ap", LearnerClustAP)
   x$add("clust.meanshift", LearnerClustMeanShift)
+  x$add("clust.hclust", LearnerClustHclust)
 
   x = utils::getFromNamespace("mlr_measures", ns = "mlr3")
   x$add("clust.db", MeasureClustInternal, name = "db")
   x$add("clust.dunn", MeasureClustInternal, name = "dunn")
   x$add("clust.ch", MeasureClustInternal, name = "ch")
   x$add("clust.silhouette", MeasureClustInternal, name = "silhouette")
+  x$add("clust.wss", MeasureClustInternal, name = "wss")
 }
 
 .onLoad = function(libname, pkgname) { # nolint
